@@ -7,6 +7,7 @@ from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
 from jinja2 import Template
 from multiprocessing import Pool
+from functools import partial
 
 from .. import core
 from ..consts import CONFIG
@@ -35,14 +36,16 @@ def runserver(host, port):
 
 
 @cmd.command()
-def sync():
+@click.option('--last-date', default=False)
+def sync(last_date):
     """Mise à jour de la liste des clients Business ainsi que de leurs \
-    relevés de consommation des 30 derniers jours."""
+    relevés de consommation superieur a une date."""
     products = Product.all()
     for product in products:
         product.update_customers()
-        with Pool(processes=2) as pool:
-            pool.map(core.update_customer_cdr, product.customers)
+        f = partial(core.update_customer_cdr, last_date)
+        with Pool(processes=3) as pool:
+            pool.map(f, product.customers)
 
 
 @cmd.command()
