@@ -114,128 +114,188 @@ class Customer(object):
         LOGS.logger.info(log_msg)
         self.product = product.Product(product_name)
 
-    def get_cdr_from_aiguillier(self):
+    def defup_from_aiguillier(self):
+        """défuper un client qui est fupé"""
+        result = {}
+        customer_status = self.fup_status
+        for policy_name in self.product.policies:
+            status = customer_status.get(policy_name)
+            if status:
+                status = sorted(
+                    status,
+                    key=lambda x: x['datetime'],
+                    reverse=True
+                    )
+                if status[0]['status']:
+                    # si le client était fup, il faut le défup
+                    REST_CLIENT.delete(
+                        '/fup',
+                        auth=(
+                            CONFIG['AIGUILLIER']['username'],
+                            CONFIG['AIGUILLIER']['password']
+                            ),
+                        params={'customer': self.name}
+                        )
+                    url = core.database_url(**FUPDB_CREDENTIALS)
+                    with records.Database(url) as db:
+                        sql = (
+                            "INSERT INTO fup "
+                            "(customer, product, policy, datetime, status) "
+                            "VALUES "
+                            "(:name, :product, :policy, :date_time, :status)"
+                            )
+                        db.query(
+                            sql,
+                            name=self.name,
+                            product=self.product.name,
+                            policy=policy_name,
+                            date_time=datetime.now(),
+                            status=False
+                            )
+                    result = {
+                        'status': '200',
+                        'message': 'défup reussit'
+                        }
+                else:
+                    result = {
+                            'status': '201',
+                            'message': 'deja fupé'
+                            }
+            else:
+                result = {
+                        'status': '204',
+                        'message': 'produit non fupé'
+                        }
+
+            LOGS.logger.info("Defuper un client {}-{}".format(
+                self.name,
+                policy_name
+                ))
+        return result
+
+    def get_cdr_from_aiguillier(self, last_date):
         """Récupération des CDRs des 30 derniers jours
         depuis l'API d'Aiguillier pour les clients business"""
         url = core.database_url(**FUPDB_CREDENTIALS)
+        LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
         response = REST_CLIENT.get(
             '/fup',
             auth=(
                 CONFIG['AIGUILLIER']['username'],
                 CONFIG['AIGUILLIER']['password']
                 ),
-            params={'customer': self.name}
+            params={'customer': self.name, 'fromdate': last_date}
             )
         infos = response['content']
-        nill_condition = (
-            'refnum' not in infos or
-            infos['product'] not in [i.name for i in product.Product.all()]
+        # nill_condition = (
+        #    'refnum' not in infos or
+        #    infos['product'] not in [i.name for i in product.Product.all()]
+        #    )
+        # if nill_condition:
+        # le client n'existe plus
+        # ou son produit a changé et il n'est plus concerné
+        # par le fup
+        #    customer_status = self.fup_status
+        #    for policy_name in self.product.policies:
+        #        status = customer_status.get(policy_name)
+        #        if status:
+        #            status = sorted(
+        #                status,
+        #                key=lambda x: x['datetime'],
+        #                reverse=True
+        #                )
+        #            if status[0]['status']:
+        #                # si le client était fup, il faut le défup
+        #                REST_CLIENT.delete(
+        #                    '/fup',
+        #                    auth=(
+        #                        CONFIG['AIGUILLIER']['username'],
+        #                        CONFIG['AIGUILLIER']['password']
+        #                        ),
+        #                    params={'customer': self.name}
+        #                    )
+        #    url = core.database_url(**FUPDB_CREDENTIALS)
+        #    with records.Database(url) as db:
+        #        sql = "DELETE FROM customer WHERE name=:name"
+        #        db.query(sql, name=self.name)
+        #        sql = "DELETE FROM cdr WHERE customer=:name"
+        #        db.query(sql, name=self.name)
+        #        sql = "DELETE FROM fup WHERE customer=:name"
+        #        db.query(sql, name=self.name)
+        #    LOGS.logger.info("Suppression du client {}".format(self.name))
+        #    return None
+        # else:
+        cdrs = sorted(
+            infos.get('cdr', []),
+            key=lambda x: datetime.strptime(
+                x['sessiontime'],
+                '%Y-%m-%dT%H:%M:%S'
+                )
             )
-        if nill_condition:
-            # le client n'existe plus
-            # ou son produit a changé et il n'est plus concerné
-            # par le fup
-            customer_status = self.fup_status
-            for policy_name in self.product.policies:
-                status = customer_status.get(policy_name)
-                if status:
-                    status = sorted(
-                        status,
-                        key=lambda x: x['datetime'],
-                        reverse=True
-                        )
-                    if status[0]['status']:
-                        # si le client était fup, il faut le défup
-                        REST_CLIENT.delete(
-                            '/fup',
-                            auth=(
-                                CONFIG['AIGUILLIER']['username'],
-                                CONFIG['AIGUILLIER']['password']
-                                ),
-                            params={'customer': self.name}
-                            )
-            url = core.database_url(**FUPDB_CREDENTIALS)
-            with records.Database(url) as db:
-                sql = "DELETE FROM customer WHERE name=:name"
-                db.query(sql, name=self.name)
-                sql = "DELETE FROM cdr WHERE customer=:name"
-                db.query(sql, name=self.name)
-                sql = "DELETE FROM fup WHERE customer=:name"
-                db.query(sql, name=self.name)
-            LOGS.logger.info("Suppression du client {}".format(self.name))
-            return None
-        else:
-            cdrs = sorted(
-                infos.get('cdr', []),
-                key=lambda x: datetime.strptime(
-                    x['sessiontime'],
+        cdrs = groupby(
+            cdrs,
+            key=lambda x: datetime.strptime(
+                x['sessiontime'].split('T')[0],
+                '%Y-%m-%d'
+                )
+            )
+        result = {}
+        params = []
+        for date, infos in cdrs:
+            LOGS.logger.info(
+                "{} {} obtenu depuis Aiguillier".format(
+                    self.name,
+                    date.strftime('%d%m%Y')
+                    )
+                )
+            result[date.strftime('%d%m%Y')] = []
+            for info in infos:
+                date_time = datetime.strptime(
+                    info['sessiontime'],
                     '%Y-%m-%dT%H:%M:%S'
                     )
-                )
-            cdrs = groupby(
-                cdrs,
-                key=lambda x: datetime.strptime(
-                    x['sessiontime'].split('T')[0],
-                    '%Y-%m-%d'
-                    )
-                )
-            result = {}
-            params = []
-            for date, infos in cdrs:
-                LOGS.logger.info(
-                    "{} {} obtenu depuis Aiguillier".format(
-                        self.name,
-                        date.strftime('%d%m%Y')
-                        )
-                    )
-                result[date.strftime('%d%m%Y')] = []
-                for info in infos:
-                    date_time = datetime.strptime(
-                        info['sessiontime'],
-                        '%Y-%m-%dT%H:%M:%S'
-                        )
-                    params.append(
-                        {
-                            'name': self.name,
-                            'product': self.product.name,
-                            'date_time': date_time,
-                            'source': info['source'],
-                            'octetsin': info.get('octetsin', 0),
-                            'octetsout': info.get('octetsout', 0)
-                            }
-                        )
-                    time = info['sessiontime'].split('T')[1].replace(':', '')
-                    values = {
-                        'octets_in': info['octetsin'],
-                        'octets_out': info['octetsout']
+                params.append(
+                    {
+                        'name': self.name,
+                        'product': self.product.name,
+                        'date_time': date_time,
+                        'source': info['source'],
+                        'octetsin': info.get('octetsin', 0),
+                        'octetsout': info.get('octetsout', 0)
                         }
-                    values['time'] = datetime.strptime(time, '%H%M%S')
-                    values['source'] = info['source']
-                    values['date'] = date
-                    result[date.strftime('%d%m%Y')].append(values)
-                with records.Database(url) as db:
-                    sql = (
-                        "DELETE FROM cdr WHERE customer=:name "
-                        "AND datetime>=:start AND datetime<=:stop"
-                        )
-                    db.query(
-                        sql,
-                        name=self.name,
-                        start=date.strftime('%Y-%m-%d 00:00:00'),
-                        stop=date.strftime('%Y-%m-%d 23:59:59')
-                        )
-            if params:
-                with records.Database(url) as db:
-                    sql = (
-                        "INSERT INTO cdr "
-                        "(customer, datetime, source, "
-                        "octets_in, octets_out, product) "
-                        "VALUES "
-                        "(:name, :date_time, :source, "
-                        ":octetsin, :octetsout, :product)"
-                        )
-                    db.bulk_query(sql, *params)
-            return result
+                    )
+                time = info['sessiontime'].split('T')[1].replace(':', '')
+                values = {
+                    'octets_in': info['octetsin'],
+                    'octets_out': info['octetsout']
+                    }
+                values['time'] = datetime.strptime(time, '%H%M%S')
+                values['source'] = info['source']
+                values['date'] = date
+                result[date.strftime('%d%m%Y')].append(values)
+            with records.Database(url) as db:
+                sql = (
+                    "DELETE FROM cdr WHERE customer=:name "
+                    "AND datetime>=:start AND datetime<=:stop"
+                    )
+                db.query(
+                    sql,
+                    name=self.name,
+                    start=date.strftime('%Y-%m-%d 00:00:00'),
+                    stop=date.strftime('%Y-%m-%d 23:59:59')
+                    )
+        if params:
+            with records.Database(url) as db:
+                sql = (
+                    "INSERT INTO cdr "
+                    "(customer, datetime, source, "
+                    "octets_in, octets_out, product) "
+                    "VALUES "
+                    "(:name, :date_time, :source, "
+                    ":octetsin, :octetsout, :product)"
+                    )
+                db.bulk_query(sql, *params)
+        return result
 
     def get_cdr(self, start=None, stop=None):
         """Récupération des données de conso d'un client business.
